@@ -7,7 +7,7 @@ from django.db import transaction
 from django.db.models import UUIDField, CharField, UniqueConstraint, Q
 from django.forms import model_to_dict
 
-from isc_common import setAttr, delAttr
+from isc_common import setAttr, delAttr, Stack
 from isc_common.auth.http.LoginRequets import LoginRequest
 from isc_common.auth.models.user import User
 from isc_common.fields.description_field import DescriptionField
@@ -329,16 +329,15 @@ class MessagesManager(CommonTreeGridManager):
                     Messages_files_refs.objects.filter(message=message).delete()
                     qty, _ = message.delete()
 
-                    if request.user_id != message.user.id:
-                        if not message.user.props.bot.is_set:
-                            LoginRequest.send_bot_message(user=message.to_whom.id,
-                                                          bot=MessagesManager.get_tracker_bot(),
-                                                          message=f'<h3>Удаление дела:</h3> #{message.guid}'
-                                                                  f'<p/>Тема: {message.theme.full_name}'
-                                                                  f'<p/>{MessagesManager.get_border(message.message, request.user)}'
-                                                                  f'<p/>Статус: {message.state.name}'
-                                                                  f'''<p/>Важность: {message.importance.name if message.importance else 'Не определена'}'''
-                                                                  f'<p/>Удалил: {request.user.get_short_name}'
+                    if request.user_id != message.user.id and message.user.props.bot.is_set is False:
+                        LoginRequest.send_bot_message(user=message.to_whom.id,
+                                                      bot=MessagesManager.get_tracker_bot(),
+                                                      message=f'<h3>Удаление дела:</h3> #{message.guid}'
+                                                              f'<p/>Тема: {message.theme.full_name}'
+                                                              f'<p/>{MessagesManager.get_border(message.message, request.user)}'
+                                                              f'<p/>Статус: {message.state.name}'
+                                                              f'''<p/>Важность: {message.importance.name if message.importance else 'Не определена'}'''
+                                                              f'<p/>Удалил: {request.user.get_short_name}'
                                                           )
                     res += qty
         return res
